/**
 * Create an audio version of your posts, with a selection of more than 200 voices across 35+ languages and variants.
 * Exclusively on Envato Market: https://1.envato.market/speaker
 *
 * @encoding        UTF-8
 * @version         2.1.1
 * @copyright       Copyright (C) 2018 - 2020 Merkulove ( https://merkulov.design/ ). All rights reserved.
 * @license         Envato License https://1.envato.market/KYbje
 * @contributors    Alexander Khmelnitskiy (info@alexander.khmelnitskiy.ua), Dmitry Merkulov (dmitry@merkulov.design)
 * @support         help@merkulov.design
 **/

( function ( $ ) {

    "use strict";

    $( document ).ready( function () {

        /** Make table great again! */
        $( '#mdp-speaker-settings-language-tbl' ).removeClass('hidden');
        let lang_table = $( '#mdp-speaker-settings-language-tbl' ).DataTable( {

            /** Show entries. */
            lengthMenu: [ [-1], ["All"] ],

            /** Add filters to table footer. */
            initComplete: function () {
                this.api().columns().every(function () {
                    let column = this;
                    let select = $( '#mdp-speaker-language-filter' );

                    /** Create filter only for first column. */
                    if ( column[0][0] != 0 ) { return; }

                    select.on( 'change', function () {

                        $( '#mdp-speaker-settings-language-tbl tbody' ).show();
                        $( '#mdp-speaker-settings-language-tbl_info' ).show();
                        $( '#mdp-speaker-settings-language-tbl_paginate' ).hide();
                        $( '#mdp-speaker-settings-language-tbl_length' ).hide();
                        $( '#mdp-speaker-settings-language-tbl thead' ).show();

                        let val = $.fn.dataTable.util.escapeRegex( $(this).val() );
                        if ( '0' === val ) { val = ''; }
                        column.search( val ? '^' + val + '$' : '', true, false ).draw();
                    } );

                } );

                // Hide all lines on first load.
                $( '#mdp-speaker-settings-language-tbl tbody' ).hide();
                $( '#mdp-speaker-settings-language-tbl_info' ).hide();
                $( '#mdp-speaker-settings-language-tbl_paginate' ).hide();
                $( '#mdp-speaker-settings-language-tbl_length' ).hide();
                $( '#mdp-speaker-settings-language-tbl thead' ).hide();
            }
        } );

        /** Select language. */
        $( '#mdp-speaker-settings-language-tbl tbody' ).on( 'click', 'tr', function ( e ) {
            $( '#mdp-speaker-settings-language-tbl tr.selected' ).removeClass( 'selected' );
            $( this ).addClass( 'selected' );

            var voice_name = $( '#mdp-speaker-settings-language-tbl tr.selected .mdp-voice-name' ).attr("title");
            var lang_code = $( '#mdp-speaker-settings-language-tbl tr.selected .mdp-lang-code' ).text();
            $( '.mdp-now-used strong' ).html( voice_name );
            $( '#mdp-speaker-settings-language' ).val( voice_name );
            $( '#mdp-speaker-settings-language-code' ).val( lang_code );

            // Update Audio Sample.
            var audio = $( '.mdp-now-used audio' );
            $( '.mdp-now-used audio source' ).attr( 'src', 'https://cloud.google.com/text-to-speech/docs/audio/' + voice_name + '.mp3' );
            audio[0].pause();
            audio[0].load();
        } );

        /** The "Select Key File" button. */
        $( '.mdp-select-key-file-btn' ).on( 'click', function( e ) {
            e.preventDefault();
            let button = $( this );
            let key_uploader = wp.media({
                title: 'Select or Upload API Key File',
                button: {
                    text: 'Use this API Key'
                },
                library: {
                    type: [ 'json', 'text' ]
                },
                multiple: false  // Select only one file.
            })
            .on('select', function() {
                let attachment = key_uploader.state().get('selection').first().toJSON();
                $( button ).prev().val( attachment.id );
                $( button ).next().text( attachment.filename );

                $( '#submit' ).trigger( 'click' );
            })
            .open();
        });

    } );

} ( jQuery ) );
